toga-django
===========

A Django backend for the `Toga widget toolkit`_.

**Toga requires Python 3**

This package isn't much use by itself; it needs to be combined with `the core Toga library`_.

For more details, see the `Toga project on Github`_.

Prerequisites
~~~~~~~~~~~~~

This backend requires Django 1.8 as a minimum requirement.

Community
---------

Toga is part of the `BeeWare suite`_. You can talk to the community through:

* `@pybeeware on Twitter`_

* The `pybee/general`_ channel on Gitter.

Contributing
------------

If you experience problems with this backend, `log them on GitHub`_. If you
want to contribute code, please `fork the code`_ and `submit a pull request`_.

.. _Toga widget toolkit: http://pybee.org/toga
.. _the core Toga library: https://pypi.python.org/pypi/toga-core
.. _Toga project on Github: https://github.com/pybee/toga
.. _BeeWare suite: http://pybee.org
.. _@pybeeware on Twitter: https://twitter.com/pybeeware
.. _pybee/general: https://gitter.im/pybee/general
.. _log them on Github: https://github.com/pybee/toga/issues
.. _fork the code: https://github.com/pybee/toga
.. _submit a pull request: https://github.com/pybee/toga/pulls
